
# Slot: object




URI: [biolink:anatomical_entity_to_anatomical_entity_ontogenic_association_object](https://w3id.org/biolink/vocab/anatomical_entity_to_anatomical_entity_ontogenic_association_object)

## Domain and Range

[AnatomicalEntityToAnatomicalEntityOntogenicAssociation](AnatomicalEntityToAnatomicalEntityOntogenicAssociation.md) ->  <sub>REQ</sub> [AnatomicalEntity](AnatomicalEntity.md)

## Parents

 *  is_a: [object](anatomical_entity_to_anatomical_entity_association_object.md)

## Children


## Used by

 * [AnatomicalEntityToAnatomicalEntityOntogenicAssociation](AnatomicalEntityToAnatomicalEntityOntogenicAssociation.md)
